# trieve_py_client
Trieve OpenAPI Specification. This document describes all of the operations available through the Trieve API.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.13.0
- Package version: 0.12.9
- Generator version: 7.4.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://trieve.ai](https://trieve.ai)

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import trieve_py_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import trieve_py_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import trieve_py_client
from trieve_py_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.trieve.ai
# See configuration.py for a list of all supported configuration parameters.
configuration = trieve_py_client.Configuration(
    host = "https://api.trieve.ai"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKey
configuration.api_key['ApiKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKey'] = 'Bearer'


# Enter a context with an instance of the API client
with trieve_py_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = trieve_py_client.AnalyticsApi(api_client)
    get_events_request_body = trieve_py_client.GetEventsRequestBody() # GetEventsRequestBody | JSON request payload to filter the events

    try:
        # Get All User Events
        api_response = api_instance.get_all_events(get_events_request_body)
        print("The response of AnalyticsApi->get_all_events:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AnalyticsApi->get_all_events: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.trieve.ai*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AnalyticsApi* | [**get_all_events**](docs/AnalyticsApi.md#get_all_events) | **POST** /api/analytics/events/all | Get All User Events
*AnalyticsApi* | [**get_cluster_analytics**](docs/AnalyticsApi.md#get_cluster_analytics) | **POST** /api/analytics/search/cluster | Get Cluster Analytics
*AnalyticsApi* | [**get_ctr_analytics**](docs/AnalyticsApi.md#get_ctr_analytics) | **POST** /api/analytics/events/ctr | Get CTR Analytics
*AnalyticsApi* | [**get_event_by_id**](docs/AnalyticsApi.md#get_event_by_id) | **GET** /api/analytics/events/{event_id} | Get User Event By ID
*AnalyticsApi* | [**get_rag_analytics**](docs/AnalyticsApi.md#get_rag_analytics) | **POST** /api/analytics/rag | Get RAG Analytics
*AnalyticsApi* | [**get_recommendation_analytics**](docs/AnalyticsApi.md#get_recommendation_analytics) | **POST** /api/analytics/recommendations | Get Recommendation Analytics
*AnalyticsApi* | [**get_search_analytics**](docs/AnalyticsApi.md#get_search_analytics) | **POST** /api/analytics/search | Get Search Analytics
*AnalyticsApi* | [**get_top_datasets**](docs/AnalyticsApi.md#get_top_datasets) | **POST** /api/analytics/top | Get Top Datasets
*AnalyticsApi* | [**send_ctr_data**](docs/AnalyticsApi.md#send_ctr_data) | **PUT** /api/analytics/ctr | Send CTR Data
*AnalyticsApi* | [**send_event_data**](docs/AnalyticsApi.md#send_event_data) | **PUT** /api/analytics/events | Send User Event Data
*AnalyticsApi* | [**set_rag_query_rating**](docs/AnalyticsApi.md#set_rag_query_rating) | **PUT** /api/analytics/rag | Rate RAG
*AnalyticsApi* | [**set_search_query_rating**](docs/AnalyticsApi.md#set_search_query_rating) | **PUT** /api/analytics/search | Rate Search
*AuthApi* | [**callback**](docs/AuthApi.md#callback) | **GET** /api/auth/callback | OpenID Connect callback
*AuthApi* | [**get_me**](docs/AuthApi.md#get_me) | **GET** /api/auth/me | Get Me
*AuthApi* | [**login**](docs/AuthApi.md#login) | **GET** /api/auth | Login
*AuthApi* | [**logout**](docs/AuthApi.md#logout) | **DELETE** /api/auth | Logout
*ChunkApi* | [**autocomplete**](docs/ChunkApi.md#autocomplete) | **POST** /api/chunk/autocomplete | Autocomplete
*ChunkApi* | [**bulk_delete_chunk**](docs/ChunkApi.md#bulk_delete_chunk) | **DELETE** /api/chunk | Bulk Delete Chunks
*ChunkApi* | [**count_chunks**](docs/ChunkApi.md#count_chunks) | **POST** /api/chunk/count | Count chunks above threshold
*ChunkApi* | [**create_chunk**](docs/ChunkApi.md#create_chunk) | **POST** /api/chunk | Create or Upsert Chunk or Chunks
*ChunkApi* | [**delete_chunk**](docs/ChunkApi.md#delete_chunk) | **DELETE** /api/chunk/{chunk_id} | Delete Chunk
*ChunkApi* | [**delete_chunk_by_tracking_id**](docs/ChunkApi.md#delete_chunk_by_tracking_id) | **DELETE** /api/chunk/tracking_id/{tracking_id} | Delete Chunk By Tracking Id
*ChunkApi* | [**generate_off_chunks**](docs/ChunkApi.md#generate_off_chunks) | **POST** /api/chunk/generate | RAG on Specified Chunks
*ChunkApi* | [**get_chunk_by_id**](docs/ChunkApi.md#get_chunk_by_id) | **GET** /api/chunk/{chunk_id} | Get Chunk By Id
*ChunkApi* | [**get_chunk_by_tracking_id**](docs/ChunkApi.md#get_chunk_by_tracking_id) | **GET** /api/chunk/tracking_id/{tracking_id} | Get Chunk By Tracking Id
*ChunkApi* | [**get_chunks_by_ids**](docs/ChunkApi.md#get_chunks_by_ids) | **POST** /api/chunks | Get Chunks By Ids
*ChunkApi* | [**get_chunks_by_tracking_ids**](docs/ChunkApi.md#get_chunks_by_tracking_ids) | **POST** /api/chunks/tracking | Get Chunks By Tracking Ids
*ChunkApi* | [**get_recommended_chunks**](docs/ChunkApi.md#get_recommended_chunks) | **POST** /api/chunk/recommend | Get Recommended Chunks
*ChunkApi* | [**get_suggested_queries**](docs/ChunkApi.md#get_suggested_queries) | **POST** /api/chunk/suggestions | Generate suggested queries
*ChunkApi* | [**scroll_dataset_chunks**](docs/ChunkApi.md#scroll_dataset_chunks) | **POST** /api/chunks/scroll | Scroll Chunks
*ChunkApi* | [**search_chunks**](docs/ChunkApi.md#search_chunks) | **POST** /api/chunk/search | Search
*ChunkApi* | [**split_html_content**](docs/ChunkApi.md#split_html_content) | **POST** /api/chunk/split | Split HTML Content into Chunks
*ChunkApi* | [**update_chunk**](docs/ChunkApi.md#update_chunk) | **PUT** /api/chunk | Update Chunk
*ChunkApi* | [**update_chunk_by_tracking_id**](docs/ChunkApi.md#update_chunk_by_tracking_id) | **PUT** /api/chunk/tracking_id/update | Update Chunk By Tracking Id
*ChunkGroupApi* | [**add_chunk_to_group**](docs/ChunkGroupApi.md#add_chunk_to_group) | **POST** /api/chunk_group/chunk/{group_id} | Add Chunk to Group
*ChunkGroupApi* | [**add_chunk_to_group_by_tracking_id**](docs/ChunkGroupApi.md#add_chunk_to_group_by_tracking_id) | **POST** /api/chunk_group/tracking_id/{tracking_id} | Add Chunk to Group by Tracking ID
*ChunkGroupApi* | [**count_group_chunks**](docs/ChunkGroupApi.md#count_group_chunks) | **POST** /api/chunk_group/count | Count Chunks in a Group
*ChunkGroupApi* | [**create_chunk_group**](docs/ChunkGroupApi.md#create_chunk_group) | **POST** /api/chunk_group | Create or Upsert Group or Groups
*ChunkGroupApi* | [**delete_chunk_group**](docs/ChunkGroupApi.md#delete_chunk_group) | **DELETE** /api/chunk_group/{group_id} | Delete Group
*ChunkGroupApi* | [**delete_group_by_tracking_id**](docs/ChunkGroupApi.md#delete_group_by_tracking_id) | **DELETE** /api/chunk_group/tracking_id/{tracking_id} | Delete Group by Tracking ID
*ChunkGroupApi* | [**get_chunk_group**](docs/ChunkGroupApi.md#get_chunk_group) | **GET** /api/chunk_group/{group_id} | Get Group
*ChunkGroupApi* | [**get_chunks_in_group**](docs/ChunkGroupApi.md#get_chunks_in_group) | **GET** /api/chunk_group/{group_id}/{page} | Get Chunks in Group
*ChunkGroupApi* | [**get_chunks_in_group_by_tracking_id**](docs/ChunkGroupApi.md#get_chunks_in_group_by_tracking_id) | **GET** /api/chunk_group/tracking_id/{group_tracking_id}/{page} | Get Chunks in Group by Tracking ID
*ChunkGroupApi* | [**get_group_by_tracking_id**](docs/ChunkGroupApi.md#get_group_by_tracking_id) | **GET** /api/chunk_group/tracking_id/{tracking_id} | Get Group by Tracking ID
*ChunkGroupApi* | [**get_groups_for_chunks**](docs/ChunkGroupApi.md#get_groups_for_chunks) | **POST** /api/chunk_group/chunks | Get Groups for Chunks
*ChunkGroupApi* | [**get_groups_for_dataset**](docs/ChunkGroupApi.md#get_groups_for_dataset) | **GET** /api/dataset/groups/{dataset_id}/{page} | Get Groups for Dataset
*ChunkGroupApi* | [**get_recommended_groups**](docs/ChunkGroupApi.md#get_recommended_groups) | **POST** /api/chunk_group/recommend | Get Recommended Groups
*ChunkGroupApi* | [**remove_chunk_from_group**](docs/ChunkGroupApi.md#remove_chunk_from_group) | **DELETE** /api/chunk_group/chunk/{group_id} | Remove Chunk from Group
*ChunkGroupApi* | [**search_over_groups**](docs/ChunkGroupApi.md#search_over_groups) | **POST** /api/chunk_group/group_oriented_search | Search Over Groups
*ChunkGroupApi* | [**search_within_group**](docs/ChunkGroupApi.md#search_within_group) | **POST** /api/chunk_group/search | Search Within Group
*ChunkGroupApi* | [**update_chunk_group**](docs/ChunkGroupApi.md#update_chunk_group) | **PUT** /api/chunk_group | Update Group
*DatasetApi* | [**batch_create_datasets**](docs/DatasetApi.md#batch_create_datasets) | **POST** /api/dataset/batch_create_datasets | Batch Create Datasets
*DatasetApi* | [**clear_dataset**](docs/DatasetApi.md#clear_dataset) | **PUT** /api/dataset/clear/{dataset_id} | Clear Dataset
*DatasetApi* | [**create_dataset**](docs/DatasetApi.md#create_dataset) | **POST** /api/dataset | Create Dataset
*DatasetApi* | [**create_etl_job**](docs/DatasetApi.md#create_etl_job) | **POST** /api/etl/create_job | Create ETL Job
*DatasetApi* | [**create_pagefind_index_for_dataset**](docs/DatasetApi.md#create_pagefind_index_for_dataset) | **PUT** /api/dataset/pagefind | Create Pagefind Index for Dataset
*DatasetApi* | [**delete_dataset**](docs/DatasetApi.md#delete_dataset) | **DELETE** /api/dataset/{dataset_id} | Delete Dataset
*DatasetApi* | [**delete_dataset_by_tracking_id**](docs/DatasetApi.md#delete_dataset_by_tracking_id) | **DELETE** /api/dataset/tracking_id/{tracking_id} | Delete Dataset by Tracking ID
*DatasetApi* | [**get_all_tags**](docs/DatasetApi.md#get_all_tags) | **POST** /api/dataset/get_all_tags | Get All Tags
*DatasetApi* | [**get_dataset**](docs/DatasetApi.md#get_dataset) | **GET** /api/dataset/{dataset_id} | Get Dataset By ID
*DatasetApi* | [**get_dataset_by_tracking_id**](docs/DatasetApi.md#get_dataset_by_tracking_id) | **GET** /api/dataset/tracking_id/{tracking_id} | Get Dataset by Tracking ID
*DatasetApi* | [**get_dataset_crawl_options**](docs/DatasetApi.md#get_dataset_crawl_options) | **GET** /api/dataset/crawl_options/{dataset_id} | Get Dataset Crawl Options
*DatasetApi* | [**get_datasets_from_organization**](docs/DatasetApi.md#get_datasets_from_organization) | **GET** /api/dataset/organization/{organization_id} | Get Datasets from Organization
*DatasetApi* | [**get_events**](docs/DatasetApi.md#get_events) | **POST** /api/dataset/events | Get events for the dataset
*DatasetApi* | [**get_pagefind_index_for_dataset**](docs/DatasetApi.md#get_pagefind_index_for_dataset) | **GET** /api/dataset/pagefind | Get Pagefind Index Url for Dataset
*DatasetApi* | [**get_usage_by_dataset_id**](docs/DatasetApi.md#get_usage_by_dataset_id) | **GET** /api/dataset/usage/{dataset_id} | Get Usage By Dataset ID
*DatasetApi* | [**update_dataset**](docs/DatasetApi.md#update_dataset) | **PUT** /api/dataset | Update Dataset by ID or Tracking ID
*FileApi* | [**create_presigned_url_for_csv_jsonl**](docs/FileApi.md#create_presigned_url_for_csv_jsonl) | **POST** /api/file/csv_or_jsonl | Create Presigned CSV/JSONL S3 PUT URL
*FileApi* | [**delete_file_handler**](docs/FileApi.md#delete_file_handler) | **DELETE** /api/file/{file_id} | Delete File
*FileApi* | [**get_dataset_files_handler**](docs/FileApi.md#get_dataset_files_handler) | **GET** /api/dataset/files/{dataset_id}/{page} | Get Files for Dataset
*FileApi* | [**get_file_handler**](docs/FileApi.md#get_file_handler) | **GET** /api/file/{file_id} | Get File Signed URL
*FileApi* | [**upload_file_handler**](docs/FileApi.md#upload_file_handler) | **POST** /api/file | Upload File
*FileApi* | [**upload_html_page**](docs/FileApi.md#upload_html_page) | **POST** /api/file/html_page | Upload HTML Page
*HealthApi* | [**health_check**](docs/HealthApi.md#health_check) | **GET** /api/health | Health Check
*InvitationApi* | [**delete_invitation**](docs/InvitationApi.md#delete_invitation) | **DELETE** /api/invitation/{invitation_id} | Delete Invitation
*InvitationApi* | [**get_invitations**](docs/InvitationApi.md#get_invitations) | **GET** /api/invitations/{organization_id} | Get Invitations
*InvitationApi* | [**post_invitation**](docs/InvitationApi.md#post_invitation) | **POST** /api/invitation | Send Invitation
*MessageApi* | [**create_message**](docs/MessageApi.md#create_message) | **POST** /api/message | Create message
*MessageApi* | [**edit_message**](docs/MessageApi.md#edit_message) | **PUT** /api/message | Edit message
*MessageApi* | [**get_all_topic_messages**](docs/MessageApi.md#get_all_topic_messages) | **GET** /api/messages/{messages_topic_id} | Get all messages for a given topic
*MessageApi* | [**get_message_by_id**](docs/MessageApi.md#get_message_by_id) | **GET** /api/message/{message_id} | Get a message by its ID
*MessageApi* | [**regenerate_message**](docs/MessageApi.md#regenerate_message) | **DELETE** /api/message | Regenerate message
*MessageApi* | [**regenerate_message_patch**](docs/MessageApi.md#regenerate_message_patch) | **PATCH** /api/message | Regenerate message
*MetricsApi* | [**get_metrics**](docs/MetricsApi.md#get_metrics) | **POST** /metrics | Get Prometheus Metrics
*OrganizationApi* | [**create_organization**](docs/OrganizationApi.md#create_organization) | **POST** /api/organization | Create Organization
*OrganizationApi* | [**create_organization_api_key**](docs/OrganizationApi.md#create_organization_api_key) | **POST** /api/organization/api_key | Create Organization Api Key
*OrganizationApi* | [**delete_organization**](docs/OrganizationApi.md#delete_organization) | **DELETE** /api/organization/{organization_id} | Delete Organization
*OrganizationApi* | [**delete_organization_api_key**](docs/OrganizationApi.md#delete_organization_api_key) | **DELETE** /api/organization/api_key/{api_key_id} | Delete Organization Api Key
*OrganizationApi* | [**get_organization**](docs/OrganizationApi.md#get_organization) | **GET** /api/organization/{organization_id} | Get Organization
*OrganizationApi* | [**get_organization_api_keys**](docs/OrganizationApi.md#get_organization_api_keys) | **GET** /api/organization/api_key | Get Organization Api Keys
*OrganizationApi* | [**get_organization_usage**](docs/OrganizationApi.md#get_organization_usage) | **GET** /api/organization/usage/{organization_id} | Get Organization Usage
*OrganizationApi* | [**get_organization_users**](docs/OrganizationApi.md#get_organization_users) | **GET** /api/organization/users/{organization_id} | Get Organization Users
*OrganizationApi* | [**update_all_org_dataset_configs**](docs/OrganizationApi.md#update_all_org_dataset_configs) | **POST** /api/organization/update_dataset_configs | Update All Dataset Configurations
*OrganizationApi* | [**update_organization**](docs/OrganizationApi.md#update_organization) | **PUT** /api/organization | Update Organization
*PublicApi* | [**public_page**](docs/PublicApi.md#public_page) | **GET** /api/public_page/{dataset_id} | 
*StripeApi* | [**cancel_subscription**](docs/StripeApi.md#cancel_subscription) | **DELETE** /api/stripe/subscription/{subscription_id} | Cancel Subscription
*StripeApi* | [**create_setup_checkout_session**](docs/StripeApi.md#create_setup_checkout_session) | **POST** /api/stripe/checkout/setup/{organization_id} | Create checkout session setup
*StripeApi* | [**direct_to_payment_link**](docs/StripeApi.md#direct_to_payment_link) | **GET** /api/stripe/payment_link/{plan_id}/{organization_id} | Checkout
*StripeApi* | [**get_all_invoices**](docs/StripeApi.md#get_all_invoices) | **GET** /api/stripe/invoices/{organization_id} | Get All Invoices
*StripeApi* | [**get_all_plans**](docs/StripeApi.md#get_all_plans) | **GET** /api/stripe/plans | Get All Plans
*StripeApi* | [**update_subscription_plan**](docs/StripeApi.md#update_subscription_plan) | **PATCH** /api/stripe/subscription_plan/{subscription_id}/{plan_id} | Update Subscription Plan
*TopicApi* | [**clone_topic**](docs/TopicApi.md#clone_topic) | **POST** /api/topic/clone | Clone Topic
*TopicApi* | [**create_topic**](docs/TopicApi.md#create_topic) | **POST** /api/topic | Create Topic
*TopicApi* | [**delete_topic**](docs/TopicApi.md#delete_topic) | **DELETE** /api/topic/{topic_id} | Delete Topic
*TopicApi* | [**get_all_topics_for_owner_id**](docs/TopicApi.md#get_all_topics_for_owner_id) | **GET** /api/topic/owner/{owner_id} | Get All Topics for Owner ID
*TopicApi* | [**update_topic**](docs/TopicApi.md#update_topic) | **PUT** /api/topic | Update Topic
*UserApi* | [**delete_user_api_key**](docs/UserApi.md#delete_user_api_key) | **DELETE** /api/user/api_key/{api_key_id} | Delete User Api Key
*UserApi* | [**get_user_api_keys**](docs/UserApi.md#get_user_api_keys) | **GET** /api/user/api_key | Get User Api Keys
*UserApi* | [**update_user**](docs/UserApi.md#update_user) | **PUT** /api/user | Update User Org Role


## Documentation For Models

 - [APIVersion](docs/APIVersion.md)
 - [AddChunkToGroupReqPayload](docs/AddChunkToGroupReqPayload.md)
 - [AddToCart](docs/AddToCart.md)
 - [ApiKeyRequestParams](docs/ApiKeyRequestParams.md)
 - [ApiKeyRespBody](docs/ApiKeyRespBody.md)
 - [AuthQuery](docs/AuthQuery.md)
 - [AutocompleteReqPayload](docs/AutocompleteReqPayload.md)
 - [BatchQueuedChunkResponse](docs/BatchQueuedChunkResponse.md)
 - [BulkDeleteChunkPayload](docs/BulkDeleteChunkPayload.md)
 - [ButtonTrigger](docs/ButtonTrigger.md)
 - [CTRAnalytics](docs/CTRAnalytics.md)
 - [CTRAnalyticsResponse](docs/CTRAnalyticsResponse.md)
 - [CTRDataRequestBody](docs/CTRDataRequestBody.md)
 - [CTRRecommendationsWithClicksResponse](docs/CTRRecommendationsWithClicksResponse.md)
 - [CTRRecommendationsWithoutClicksResponse](docs/CTRRecommendationsWithoutClicksResponse.md)
 - [CTRSearchQueryWithClicksResponse](docs/CTRSearchQueryWithClicksResponse.md)
 - [CTRSearchQueryWithoutClicksResponse](docs/CTRSearchQueryWithoutClicksResponse.md)
 - [CTRType](docs/CTRType.md)
 - [ChatMessageProxy](docs/ChatMessageProxy.md)
 - [ChunkFilter](docs/ChunkFilter.md)
 - [ChunkGroup](docs/ChunkGroup.md)
 - [ChunkGroupAndFileId](docs/ChunkGroupAndFileId.md)
 - [ChunkHtmlContentReqPayload](docs/ChunkHtmlContentReqPayload.md)
 - [ChunkMetadata](docs/ChunkMetadata.md)
 - [ChunkMetadataStringTagSet](docs/ChunkMetadataStringTagSet.md)
 - [ChunkMetadataTypes](docs/ChunkMetadataTypes.md)
 - [ChunkMetadataWithPosition](docs/ChunkMetadataWithPosition.md)
 - [ChunkMetadataWithScore](docs/ChunkMetadataWithScore.md)
 - [ChunkReqPayload](docs/ChunkReqPayload.md)
 - [ChunkReqPayloadFields](docs/ChunkReqPayloadFields.md)
 - [ChunkReqPayloadMapping](docs/ChunkReqPayloadMapping.md)
 - [ChunkReturnTypes](docs/ChunkReturnTypes.md)
 - [ChunkWithPosition](docs/ChunkWithPosition.md)
 - [ChunkedContent](docs/ChunkedContent.md)
 - [Click](docs/Click.md)
 - [ClickhouseRagTypes](docs/ClickhouseRagTypes.md)
 - [ClickhouseRecommendationTypes](docs/ClickhouseRecommendationTypes.md)
 - [ClickhouseSearchTypes](docs/ClickhouseSearchTypes.md)
 - [CloneTopicReqPayload](docs/CloneTopicReqPayload.md)
 - [ClusterAnalytics](docs/ClusterAnalytics.md)
 - [ClusterAnalyticsFilter](docs/ClusterAnalyticsFilter.md)
 - [ClusterAnalyticsResponse](docs/ClusterAnalyticsResponse.md)
 - [ClusterQueries](docs/ClusterQueries.md)
 - [ClusterTopics](docs/ClusterTopics.md)
 - [ConditionType](docs/ConditionType.md)
 - [ContentChunkMetadata](docs/ContentChunkMetadata.md)
 - [ContextOptions](docs/ContextOptions.md)
 - [CountChunkQueryResponseBody](docs/CountChunkQueryResponseBody.md)
 - [CountChunksReqPayload](docs/CountChunksReqPayload.md)
 - [CountQueries](docs/CountQueries.md)
 - [CountSearchMethod](docs/CountSearchMethod.md)
 - [CrawlInterval](docs/CrawlInterval.md)
 - [CrawlOpenAPIOptions](docs/CrawlOpenAPIOptions.md)
 - [CrawlOptions](docs/CrawlOptions.md)
 - [CrawlShopifyOptions](docs/CrawlShopifyOptions.md)
 - [CreateApiKeyReqPayload](docs/CreateApiKeyReqPayload.md)
 - [CreateApiKeyResponse](docs/CreateApiKeyResponse.md)
 - [CreateBatchDataset](docs/CreateBatchDataset.md)
 - [CreateChunkGroupReqPayloadEnum](docs/CreateChunkGroupReqPayloadEnum.md)
 - [CreateChunkGroupResponseEnum](docs/CreateChunkGroupResponseEnum.md)
 - [CreateChunkReqPayloadEnum](docs/CreateChunkReqPayloadEnum.md)
 - [CreateDatasetBatchReqPayload](docs/CreateDatasetBatchReqPayload.md)
 - [CreateDatasetReqPayload](docs/CreateDatasetReqPayload.md)
 - [CreateMessageReqPayload](docs/CreateMessageReqPayload.md)
 - [CreateOrganizationReqPayload](docs/CreateOrganizationReqPayload.md)
 - [CreatePresignedUrlForCsvJsonResponseBody](docs/CreatePresignedUrlForCsvJsonResponseBody.md)
 - [CreatePresignedUrlForCsvJsonlReqPayload](docs/CreatePresignedUrlForCsvJsonlReqPayload.md)
 - [CreateSchemaReqPayload](docs/CreateSchemaReqPayload.md)
 - [CreateSetupCheckoutSessionResPayload](docs/CreateSetupCheckoutSessionResPayload.md)
 - [CreateSingleChunkGroupReqPayload](docs/CreateSingleChunkGroupReqPayload.md)
 - [CreateTopicReqPayload](docs/CreateTopicReqPayload.md)
 - [Dataset](docs/Dataset.md)
 - [DatasetAnalytics](docs/DatasetAnalytics.md)
 - [DatasetAndUsage](docs/DatasetAndUsage.md)
 - [DatasetConfigurationDTO](docs/DatasetConfigurationDTO.md)
 - [DatasetDTO](docs/DatasetDTO.md)
 - [DatasetUsageCount](docs/DatasetUsageCount.md)
 - [DateRange](docs/DateRange.md)
 - [DeleteTopicData](docs/DeleteTopicData.md)
 - [DeprecatedSearchOverGroupsResponseBody](docs/DeprecatedSearchOverGroupsResponseBody.md)
 - [DistanceMetric](docs/DistanceMetric.md)
 - [Document](docs/Document.md)
 - [EditMessageReqPayload](docs/EditMessageReqPayload.md)
 - [ErrorResponseBody](docs/ErrorResponseBody.md)
 - [EventAnalyticsFilter](docs/EventAnalyticsFilter.md)
 - [EventData](docs/EventData.md)
 - [EventReturn](docs/EventReturn.md)
 - [EventTypeRequest](docs/EventTypeRequest.md)
 - [EventTypes](docs/EventTypes.md)
 - [EventTypesFilter](docs/EventTypesFilter.md)
 - [FieldCondition](docs/FieldCondition.md)
 - [File](docs/File.md)
 - [FileAndGroupId](docs/FileAndGroupId.md)
 - [FileDTO](docs/FileDTO.md)
 - [FileData](docs/FileData.md)
 - [FilterClicked](docs/FilterClicked.md)
 - [FullTextBoost](docs/FullTextBoost.md)
 - [GenerateOffChunksReqPayload](docs/GenerateOffChunksReqPayload.md)
 - [GeoInfo](docs/GeoInfo.md)
 - [GeoInfoWithBias](docs/GeoInfoWithBias.md)
 - [GeoTypes](docs/GeoTypes.md)
 - [GetAllTagsReqPayload](docs/GetAllTagsReqPayload.md)
 - [GetAllTagsResponse](docs/GetAllTagsResponse.md)
 - [GetChunkGroupCountRequest](docs/GetChunkGroupCountRequest.md)
 - [GetChunkGroupCountResponse](docs/GetChunkGroupCountResponse.md)
 - [GetChunksData](docs/GetChunksData.md)
 - [GetChunksInGroupResponse](docs/GetChunksInGroupResponse.md)
 - [GetChunksInGroupsResponseBody](docs/GetChunksInGroupsResponseBody.md)
 - [GetCrawlOptionsResponse](docs/GetCrawlOptionsResponse.md)
 - [GetDatasetsPagination](docs/GetDatasetsPagination.md)
 - [GetEventsData](docs/GetEventsData.md)
 - [GetEventsRequestBody](docs/GetEventsRequestBody.md)
 - [GetEventsResponseBody](docs/GetEventsResponseBody.md)
 - [GetGroupsForChunksReqPayload](docs/GetGroupsForChunksReqPayload.md)
 - [GetPagefindIndexResponse](docs/GetPagefindIndexResponse.md)
 - [GetTopDatasetsRequestBody](docs/GetTopDatasetsRequestBody.md)
 - [GetTrackingChunksData](docs/GetTrackingChunksData.md)
 - [Granularity](docs/Granularity.md)
 - [GroupData](docs/GroupData.md)
 - [GroupScoreChunk](docs/GroupScoreChunk.md)
 - [GroupsBookmarkQueryResult](docs/GroupsBookmarkQueryResult.md)
 - [GroupsForChunk](docs/GroupsForChunk.md)
 - [HasChunkIDCondition](docs/HasChunkIDCondition.md)
 - [HeadQueries](docs/HeadQueries.md)
 - [HeadQueries1](docs/HeadQueries1.md)
 - [HeadQueryResponse](docs/HeadQueryResponse.md)
 - [HeroPattern](docs/HeroPattern.md)
 - [HighlightOptions](docs/HighlightOptions.md)
 - [HighlightStrategy](docs/HighlightStrategy.md)
 - [ImageConfig](docs/ImageConfig.md)
 - [Invitation](docs/Invitation.md)
 - [InvitationData](docs/InvitationData.md)
 - [LLMOptions](docs/LLMOptions.md)
 - [LatencyGraph](docs/LatencyGraph.md)
 - [LatencyGraphResponse](docs/LatencyGraphResponse.md)
 - [LocationBoundingBox](docs/LocationBoundingBox.md)
 - [LocationPolygon](docs/LocationPolygon.md)
 - [LocationRadius](docs/LocationRadius.md)
 - [LowConfidenceQueries](docs/LowConfidenceQueries.md)
 - [LowConfidenceRecommendations](docs/LowConfidenceRecommendations.md)
 - [MatchCondition](docs/MatchCondition.md)
 - [Message](docs/Message.md)
 - [Metadata](docs/Metadata.md)
 - [MmrOptions](docs/MmrOptions.md)
 - [MultiQuery](docs/MultiQuery.md)
 - [NewChunkMetadataTypes](docs/NewChunkMetadataTypes.md)
 - [NoResultQueries](docs/NoResultQueries.md)
 - [OpenGraphMetadata](docs/OpenGraphMetadata.md)
 - [Organization](docs/Organization.md)
 - [OrganizationUsageCount](docs/OrganizationUsageCount.md)
 - [OrganizationWithSubAndPlan](docs/OrganizationWithSubAndPlan.md)
 - [Pdf2MdOptions](docs/Pdf2MdOptions.md)
 - [PopularFilters](docs/PopularFilters.md)
 - [PopularFilters1](docs/PopularFilters1.md)
 - [PopularFiltersResponse](docs/PopularFiltersResponse.md)
 - [PublicDatasetOptions](docs/PublicDatasetOptions.md)
 - [PublicPageParameters](docs/PublicPageParameters.md)
 - [PublicPageSearchOptions](docs/PublicPageSearchOptions.md)
 - [PublicPageTabMessage](docs/PublicPageTabMessage.md)
 - [PublicPageTag](docs/PublicPageTag.md)
 - [PublicPageTheme](docs/PublicPageTheme.md)
 - [Purchase](docs/Purchase.md)
 - [QdrantChunkMetadata](docs/QdrantChunkMetadata.md)
 - [QdrantSortBy](docs/QdrantSortBy.md)
 - [QueryCountResponse](docs/QueryCountResponse.md)
 - [QueryDetails](docs/QueryDetails.md)
 - [QueryDetails1](docs/QueryDetails1.md)
 - [QueryTypes](docs/QueryTypes.md)
 - [RAG](docs/RAG.md)
 - [RAGAnalytics](docs/RAGAnalytics.md)
 - [RAGAnalyticsFilter](docs/RAGAnalyticsFilter.md)
 - [RAGAnalyticsResponse](docs/RAGAnalyticsResponse.md)
 - [RAGQueries](docs/RAGQueries.md)
 - [RAGSortBy](docs/RAGSortBy.md)
 - [RAGUsage](docs/RAGUsage.md)
 - [RAGUsageGraph](docs/RAGUsageGraph.md)
 - [RAGUsageGraphResponse](docs/RAGUsageGraphResponse.md)
 - [RAGUsageResponse](docs/RAGUsageResponse.md)
 - [RagQueryEvent](docs/RagQueryEvent.md)
 - [RagQueryResponse](docs/RagQueryResponse.md)
 - [RagTypes](docs/RagTypes.md)
 - [Range](docs/Range.md)
 - [RangeCondition](docs/RangeCondition.md)
 - [RateQueryRequest](docs/RateQueryRequest.md)
 - [ReRankOptions](docs/ReRankOptions.md)
 - [RecommendChunksRequest](docs/RecommendChunksRequest.md)
 - [RecommendChunksResponseBody](docs/RecommendChunksResponseBody.md)
 - [RecommendGroupsReqPayload](docs/RecommendGroupsReqPayload.md)
 - [RecommendGroupsResponse](docs/RecommendGroupsResponse.md)
 - [RecommendGroupsResponseBody](docs/RecommendGroupsResponseBody.md)
 - [RecommendResponseTypes](docs/RecommendResponseTypes.md)
 - [RecommendType](docs/RecommendType.md)
 - [Recommendation](docs/Recommendation.md)
 - [RecommendationAnalytics](docs/RecommendationAnalytics.md)
 - [RecommendationAnalyticsFilter](docs/RecommendationAnalyticsFilter.md)
 - [RecommendationAnalyticsResponse](docs/RecommendationAnalyticsResponse.md)
 - [RecommendationCTRMetrics](docs/RecommendationCTRMetrics.md)
 - [RecommendationCTRMetrics1](docs/RecommendationCTRMetrics1.md)
 - [RecommendationEvent](docs/RecommendationEvent.md)
 - [RecommendationQueries](docs/RecommendationQueries.md)
 - [RecommendationStrategy](docs/RecommendationStrategy.md)
 - [RecommendationType](docs/RecommendationType.md)
 - [RecommendationsEventResponse](docs/RecommendationsEventResponse.md)
 - [RecommendationsWithClicks](docs/RecommendationsWithClicks.md)
 - [RecommendationsWithClicksCTRResponse](docs/RecommendationsWithClicksCTRResponse.md)
 - [RecommendationsWithoutClicks](docs/RecommendationsWithoutClicks.md)
 - [RecommendationsWithoutClicksCTRResponse](docs/RecommendationsWithoutClicksCTRResponse.md)
 - [RegenerateMessageReqPayload](docs/RegenerateMessageReqPayload.md)
 - [RemoveChunkFromGroupReqPayload](docs/RemoveChunkFromGroupReqPayload.md)
 - [RequestInfo](docs/RequestInfo.md)
 - [ReturnQueuedChunk](docs/ReturnQueuedChunk.md)
 - [RoleProxy](docs/RoleProxy.md)
 - [ScoreChunk](docs/ScoreChunk.md)
 - [ScoreChunkDTO](docs/ScoreChunkDTO.md)
 - [ScoringOptions](docs/ScoringOptions.md)
 - [ScrapeOptions](docs/ScrapeOptions.md)
 - [ScrapeOptionsOneOf](docs/ScrapeOptionsOneOf.md)
 - [ScrapeOptionsOneOf1](docs/ScrapeOptionsOneOf1.md)
 - [ScrapeOptionsOneOf2](docs/ScrapeOptionsOneOf2.md)
 - [ScrollChunksReqPayload](docs/ScrollChunksReqPayload.md)
 - [ScrollChunksResponseBody](docs/ScrollChunksResponseBody.md)
 - [Search](docs/Search.md)
 - [SearchAnalytics](docs/SearchAnalytics.md)
 - [SearchAnalyticsFilter](docs/SearchAnalyticsFilter.md)
 - [SearchAnalyticsResponse](docs/SearchAnalyticsResponse.md)
 - [SearchCTRMetrics](docs/SearchCTRMetrics.md)
 - [SearchCTRMetrics1](docs/SearchCTRMetrics1.md)
 - [SearchChunkQueryResponseBody](docs/SearchChunkQueryResponseBody.md)
 - [SearchChunksReqPayload](docs/SearchChunksReqPayload.md)
 - [SearchClusterResponse](docs/SearchClusterResponse.md)
 - [SearchClusterTopics](docs/SearchClusterTopics.md)
 - [SearchGroupResponseTypes](docs/SearchGroupResponseTypes.md)
 - [SearchLatencyGraph](docs/SearchLatencyGraph.md)
 - [SearchMethod](docs/SearchMethod.md)
 - [SearchMetrics](docs/SearchMetrics.md)
 - [SearchModalities](docs/SearchModalities.md)
 - [SearchModalitiesOneOf](docs/SearchModalitiesOneOf.md)
 - [SearchModalitiesOneOf1](docs/SearchModalitiesOneOf1.md)
 - [SearchOverGroupsReqPayload](docs/SearchOverGroupsReqPayload.md)
 - [SearchOverGroupsResponseBody](docs/SearchOverGroupsResponseBody.md)
 - [SearchOverGroupsResponseTypes](docs/SearchOverGroupsResponseTypes.md)
 - [SearchOverGroupsResults](docs/SearchOverGroupsResults.md)
 - [SearchQueries](docs/SearchQueries.md)
 - [SearchQueriesWithClicksCTRResponse](docs/SearchQueriesWithClicksCTRResponse.md)
 - [SearchQueriesWithoutClicksCTRResponse](docs/SearchQueriesWithoutClicksCTRResponse.md)
 - [SearchQueryEvent](docs/SearchQueryEvent.md)
 - [SearchQueryRating](docs/SearchQueryRating.md)
 - [SearchQueryResponse](docs/SearchQueryResponse.md)
 - [SearchResponseBody](docs/SearchResponseBody.md)
 - [SearchResponseTypes](docs/SearchResponseTypes.md)
 - [SearchResultType](docs/SearchResultType.md)
 - [SearchSortBy](docs/SearchSortBy.md)
 - [SearchType](docs/SearchType.md)
 - [SearchTypeCount](docs/SearchTypeCount.md)
 - [SearchUsageGraph](docs/SearchUsageGraph.md)
 - [SearchUsageGraphResponse](docs/SearchUsageGraphResponse.md)
 - [SearchWithinGroupReqPayload](docs/SearchWithinGroupReqPayload.md)
 - [SearchWithinGroupResponseBody](docs/SearchWithinGroupResponseBody.md)
 - [SearchWithinGroupResults](docs/SearchWithinGroupResults.md)
 - [SearchesWithClicks](docs/SearchesWithClicks.md)
 - [SearchesWithoutClicks](docs/SearchesWithoutClicks.md)
 - [SemanticBoost](docs/SemanticBoost.md)
 - [SingleProductOptions](docs/SingleProductOptions.md)
 - [SingleQueuedChunkResponse](docs/SingleQueuedChunkResponse.md)
 - [Sitemap](docs/Sitemap.md)
 - [SlimChunkMetadata](docs/SlimChunkMetadata.md)
 - [SlimChunkMetadataWithArrayTagSet](docs/SlimChunkMetadataWithArrayTagSet.md)
 - [SlimChunkMetadataWithScore](docs/SlimChunkMetadataWithScore.md)
 - [SlimUser](docs/SlimUser.md)
 - [SortByField](docs/SortByField.md)
 - [SortBySearchType](docs/SortBySearchType.md)
 - [SortOptions](docs/SortOptions.md)
 - [SortOrder](docs/SortOrder.md)
 - [SplitHtmlResponse](docs/SplitHtmlResponse.md)
 - [StripeInvoice](docs/StripeInvoice.md)
 - [StripePlan](docs/StripePlan.md)
 - [StripeSubscription](docs/StripeSubscription.md)
 - [SuggestType](docs/SuggestType.md)
 - [SuggestedQueriesReqPayload](docs/SuggestedQueriesReqPayload.md)
 - [SuggestedQueriesResponse](docs/SuggestedQueriesResponse.md)
 - [TagsWithCount](docs/TagsWithCount.md)
 - [TopDatasetsRequestTypes](docs/TopDatasetsRequestTypes.md)
 - [TopDatasetsResponse](docs/TopDatasetsResponse.md)
 - [Topic](docs/Topic.md)
 - [TypoOptions](docs/TypoOptions.md)
 - [TypoRange](docs/TypoRange.md)
 - [UpdateAllOrgDatasetConfigsReqPayload](docs/UpdateAllOrgDatasetConfigsReqPayload.md)
 - [UpdateChunkByTrackingIdData](docs/UpdateChunkByTrackingIdData.md)
 - [UpdateChunkGroupReqPayload](docs/UpdateChunkGroupReqPayload.md)
 - [UpdateChunkReqPayload](docs/UpdateChunkReqPayload.md)
 - [UpdateDatasetReqPayload](docs/UpdateDatasetReqPayload.md)
 - [UpdateGroupByTrackingIDReqPayload](docs/UpdateGroupByTrackingIDReqPayload.md)
 - [UpdateOrganizationReqPayload](docs/UpdateOrganizationReqPayload.md)
 - [UpdateTopicReqPayload](docs/UpdateTopicReqPayload.md)
 - [UpdateUserOrgRoleReqPayload](docs/UpdateUserOrgRoleReqPayload.md)
 - [UploadFileReqPayload](docs/UploadFileReqPayload.md)
 - [UploadFileResponseBody](docs/UploadFileResponseBody.md)
 - [UploadHtmlPageReqPayload](docs/UploadHtmlPageReqPayload.md)
 - [UsageGraphPoint](docs/UsageGraphPoint.md)
 - [UserApiKey](docs/UserApiKey.md)
 - [UserOrganization](docs/UserOrganization.md)
 - [View](docs/View.md)
 - [WorkerEvent](docs/WorkerEvent.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKey"></a>
### ApiKey

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

<a id="X-API-KEY"></a>
### X-API-KEY

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

developers@trieve.ai


